/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLAreaElement.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLAreaElement.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLAreaElement.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateIntGdomHTMLAreaElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLAreaElement::GDOMHTMLAreaElement(PassRefPtr<WebCore::HTMLAreaElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLAreaElement.h"
#include <gdom/GdomHTMLAreaElement.h>
#include <gdom/PrivateGdomHTMLAreaElement.h>
#include <gdom/PrivateIntGdomHTMLAreaElement.h>
#include <gdom/GdomHTMLAreaElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLAreaElement, gdom_html_area_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLAreaElementPrivate {
    class WebCore::HTMLAreaElement *item;
};

#define GDOM_HTML_AREA_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_AREA_ELEMENT, GdomHTMLAreaElementPrivate))
*/
G_END_DECLS
WebCore::HTMLAreaElement *
gdom_html_area_element_get_private(GdomHTMLAreaElement *request)
{
    GDOMHTMLAreaElement *res;
    res = static_cast<GDOMHTMLAreaElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLAreaElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_ACCESS_KEY,
    PROP_ALT,
    PROP_COORDS,
    PROP_HREF,
    PROP_NO_HREF,
    PROP_SHAPE,
    PROP_TARGET,
    PROP_HASH,
    PROP_HOST,
    PROP_HOSTNAME,
    PROP_PATHNAME,
    PROP_PORT,
    PROP_PROTOCOL,
    PROP_SEARCH,
};


static void gdom_html_area_element_finalize(GObject* object)
{
    /*GdomHTMLAreaElement* request = GDOM_HTML_AREA_ELEMENT(object);*/
    /*GdomHTMLAreaElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_area_element_parent_class)->finalize(object);
}

static void gdom_html_area_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAreaElement *self = GDOM_HTML_AREA_ELEMENT(object);
    WebCore::HTMLAreaElement * gself = (gdom_html_area_element_get_private(self));
    switch (prop_id) {
     case PROP_ACCESS_KEY:
    {
         gself->setAccessKey(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_ALT:
    {
         gself->setAlt(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_COORDS:
    {
         gself->setCoords(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HREF:
    {
         gself->setHref(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_NO_HREF:
    {
         gself->setNoHref((g_value_get_boolean (value)) );
         break;
    }
     case PROP_SHAPE:
    {
         gself->setShape(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TARGET:
    {
         gself->setTarget(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_area_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLAreaElement *self = GDOM_HTML_AREA_ELEMENT(object);
    WebCore::HTMLAreaElement * gself = (gdom_html_area_element_get_private(self));
    switch (prop_id) {
    case PROP_ACCESS_KEY:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->accessKey()));
         break;
    }
    case PROP_ALT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->alt()));
         break;
    }
    case PROP_COORDS:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->coords()));
         break;
    }
    case PROP_HREF:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->href()));
         break;
    }
    case PROP_NO_HREF:
    {
         g_value_set_boolean (value, gself->noHref());
         break;
    }
    case PROP_SHAPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->shape()));
         break;
    }
    case PROP_TARGET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->target()));
         break;
    }
    case PROP_HASH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hash()));
         break;
    }
    case PROP_HOST:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->host()));
         break;
    }
    case PROP_HOSTNAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->hostname()));
         break;
    }
    case PROP_PATHNAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->pathname()));
         break;
    }
    case PROP_PORT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->port()));
         break;
    }
    case PROP_PROTOCOL:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->protocol()));
         break;
    }
    case PROP_SEARCH:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->search()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_area_element_class_init(GdomHTMLAreaElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_area_element_finalize;
    g_klass->set_property = gdom_html_area_element__set_property_fn;
    g_klass->get_property = gdom_html_area_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_ACCESS_KEY,
            g_param_spec_string ("access_key", /* name */
                "html_area_element_access_key", /* short description */
                "read-write  gchar * HTMLAreaElement.access_key", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_ALT,
            g_param_spec_string ("alt", /* name */
                "html_area_element_alt", /* short description */
                "read-write  gchar * HTMLAreaElement.alt", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_COORDS,
            g_param_spec_string ("coords", /* name */
                "html_area_element_coords", /* short description */
                "read-write  gchar * HTMLAreaElement.coords", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HREF,
            g_param_spec_string ("href", /* name */
                "html_area_element_href", /* short description */
                "read-write  gchar * HTMLAreaElement.href", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_NO_HREF,
            g_param_spec_boolean ("no_href", /* name */
                "html_area_element_no_href", /* short description */
                "read-write  gboolean HTMLAreaElement.no_href", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SHAPE,
            g_param_spec_string ("shape", /* name */
                "html_area_element_shape", /* short description */
                "read-write  gchar * HTMLAreaElement.shape", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TARGET,
            g_param_spec_string ("target", /* name */
                "html_area_element_target", /* short description */
                "read-write  gchar * HTMLAreaElement.target", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HASH,
            g_param_spec_string ("hash", /* name */
                "html_area_element_hash", /* short description */
                "read-only  gchar * HTMLAreaElement.hash", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_HOST,
            g_param_spec_string ("host", /* name */
                "html_area_element_host", /* short description */
                "read-only  gchar * HTMLAreaElement.host", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_HOSTNAME,
            g_param_spec_string ("hostname", /* name */
                "html_area_element_hostname", /* short description */
                "read-only  gchar * HTMLAreaElement.hostname", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PATHNAME,
            g_param_spec_string ("pathname", /* name */
                "html_area_element_pathname", /* short description */
                "read-only  gchar * HTMLAreaElement.pathname", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PORT,
            g_param_spec_string ("port", /* name */
                "html_area_element_port", /* short description */
                "read-only  gchar * HTMLAreaElement.port", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_PROTOCOL,
            g_param_spec_string ("protocol", /* name */
                "html_area_element_protocol", /* short description */
                "read-only  gchar * HTMLAreaElement.protocol", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SEARCH,
            g_param_spec_string ("search", /* name */
                "html_area_element_search", /* short description */
                "read-only  gchar * HTMLAreaElement.search", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLAreaElementPrivate));*/
}

static void gdom_html_area_element_init(GdomHTMLAreaElement* request)
{
    /*GdomHTMLAreaElementPrivate* priv = GDOM_HTML_AREA_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

